@@ -61,6 +61,7 @@ class Server(Base):
     motd = Column(String(10), nullable=False, server_default=text("'both'"))
     power_enabled = Column(Boolean, nullable=False, server_default=true())
     tags_enabled = Column(Boolean, nullable=False, server_default=true())
+    queue_time_enabled = Column(Boolean, nullable=False, server_default=true())
     create_voice = Column(Boolean, nullable=False, server_default=false())
     smotd = Column(String(255))
     voice_category_prefix = Column(String(40))
@@ -69,6 +70,9 @@ class Server(Base):
     auto_verify_channels = relationship(
         "AutoVerifyChannel", back_populates="server", uselist=True
     )
+    unverified_only_channels = relationship(
+        "UnverifiedOnlyChannel", back_populates="server", uselist=True
+    )
     channel_settings = relationship(
         "ChannelSettings", back_populates="server", uselist=True, lazy="dynamic"
     )
@@ -204,6 +208,18 @@ class AutoVerifyChannel(Base):
     server = relationship("Server", back_populates="auto_verify_channels")
 
 
+class UnverifiedOnlyChannel(Base):
+    __tablename__ = "unverified_only_channels"
+    channel_xid = Column(BigInteger, primary_key=True, nullable=False)
+    guild_xid = Column(
+        BigInteger,
+        ForeignKey("servers.guild_xid", ondelete="CASCADE"),
+        nullable=False,
+        index=True,
+    )
+    server = relationship("Server", back_populates="unverified_only_channels")
+
+
 class ChannelSettings(Base):
     __tablename__ = "channel_settings"
     channel_xid = Column(BigInteger, primary_key=True, nullable=False)
@@ -220,6 +236,8 @@ class ChannelSettings(Base):
     require_verification = Column(Boolean, nullable=False, server_default=false())
     cmotd = Column(String(255))
     verify_message = Column(String(255))
+    tags_enabled = Column(Boolean, nullable=True)  # overrides server setting
+    queue_time_enabled = Column(Boolean, nullable=True)  # overrides server setting
     server = relationship("Server", back_populates="channel_settings")
 
 
@@ -281,6 +299,7 @@ class User(Base):
     )
     cached_name = Column(String(50))
     power = Column(Integer, nullable=True)
+    banned = Column(Boolean, nullable=False, server_default=false())
     game = relationship("Game", back_populates="users")
 
     blocks = relationship(
@@ -335,11 +354,8 @@ class User(Base):
 
     def points(self, guild_xid) -> int:
         session = Session.object_session(self)
-        results = (
-            session.query(func.sum(UserPoints.points))
-            .filter_by(user_xid=self.xid, guild_xid=guild_xid)
-            .scalar()
-        )
+        filters = and_(UserPoints.user_xid == self.xid, UserPoints.guild_xid == guild_xid)
+        results = session.query(func.sum(UserPoints.points)).filter(filters).scalar()
         return results or 0
 
     def to_json(self) -> dict:
@@ -370,6 +386,23 @@ class UserServerSettings(Base):
     verified = Column(Boolean, nullable=True, server_default=false())
 
 
+class WatchedUser(Base):
+    __tablename__ = "watched_users"
+    user_xid = Column(
+        BigInteger,
+        ForeignKey("users.xid", ondelete="CASCADE"),
+        primary_key=True,
+        nullable=False,
+    )
+    guild_xid = Column(
+        BigInteger,
+        ForeignKey("servers.guild_xid", ondelete="CASCADE"),
+        primary_key=True,
+        nullable=False,
+    )
+    note = Column(String(255))
+
+
 class UserPoints(Base):
     __tablename__ = "user_points"
     user_xid = Column(
@@ -417,6 +450,22 @@ class Tag(Base):
         return tags
 
 
+class Play(Base):
+    __tablename__ = "plays"
+    user_xid = Column(
+        BigInteger,
+        ForeignKey("users.xid", ondelete="CASCADE"),
+        primary_key=True,
+        nullable=False,
+    )
+    game_id = Column(
+        Integer,
+        ForeignKey("games.id", ondelete="CASCADE"),
+        primary_key=True,
+        nullable=False,
+    )
+
+
 class Game(Base):
     __tablename__ = "games"
     id = Column(Integer, primary_key=True, nullable=False, autoincrement=True)
@@ -436,6 +485,7 @@ class Game(Base):
         String(30), nullable=False, server_default=text("'pending'"), index=True
     )
     message = Column(String(255))
+    note = Column(String(255))
     event_id = Column(
         Integer, ForeignKey("events.id", ondelete="SET NULL"), nullable=True, index=True
     )
@@ -651,6 +701,7 @@ class Game(Base):
             "status": self.status,
             "system": self.system,
             "message": self.message,
+            "note": self.note,
             "message_xid": self.message_xid,
             "voice_channel_xid": self.voice_channel_xid,
             "voice_channel_invite": self.voice_channel_invite,
@@ -761,6 +812,10 @@ class Game(Base):
                 )
             )
             embed.add_field(name="Players", value=players, inline=False)
+
+        if self.note:
+            embed.add_field(name="Note", value=self.note, inline=False)
+
         embed.set_footer(text=f"SpellBot Reference #SB{self.id}")
         embed.color = discord.Color(0x5A3EFD)
         return embed
@@ -793,6 +848,16 @@ def reverse_all(connection: Connection, db_url: str) -> None:
     alembic.command.downgrade(config, "base")
 
 
+class Metric(Base):
+    __tablename__ = "metrics"
+    id = Column(Integer, primary_key=True, nullable=False, autoincrement=True)
+    created_at = Column(DateTime, nullable=False, default=datetime.utcnow)
+    kind = Column(String(50), index=True)
+    guild_xid = Column(BigInteger, index=True)
+    channel_xid = Column(BigInteger, index=True)
+    user_xid = Column(BigInteger, index=True)
+
+
 class Data:
     """Persistent and in-memory store for user data."""
 
